/* Name of package */
#define PACKAGE "uid_wrapper"

/* Version number of package */
#define VERSION "1.1.1"

/* #undef LOCALEDIR */
#define DATADIR "/usr/local/share/uid_wrapper"
#define LIBDIR "/usr/local/lib"
#define PLUGINDIR "/usr/local/lib/uid_wrapper-0"
#define SYSCONFDIR "/usr/local/etc"
#define BINARYDIR "/home/asn/workspace/projects/uid_wrapper/obj32"
#define SOURCEDIR "/home/asn/workspace/projects/uid_wrapper"

/************************** HEADER FILES *************************/

#define HAVE_SYS_TYPES_H 1
#define HAVE_SYS_SYSCALL_H 1
#define HAVE_SYSCALL_H 1
#define HAVE_UNISTD_H 1
#define HAVE_GRP_H 1

/*************************** FUNCTIONS ***************************/

/* Define to 1 if you have the `seteuid' function. */
#define HAVE_SETEUID 1

/* Define to 1 if you have the `setreuid' function. */
#define HAVE_SETREUID 1

/* Define to 1 if you have the `setresuid' function. */
#define HAVE_SETRESUID 1

/* Define to 1 if you have the `getresuid' function. */
#define HAVE_GETRESUID 1

/* Define to 1 if you have the `setegid' function. */
#define HAVE_SETEGID 1

/* Define to 1 if you have the `setregid' function. */
#define HAVE_SETREGID 1

/* Define to 1 if you have the `setresgid' function. */
#define HAVE_SETRESGID 1

/* Define to 1 if you have the `getresgid' function. */
#define HAVE_GETRESGID 1

/* Define to 1 if you have the `setgroups' function. */
#define HAVE_SETGROUPS 1
/* #undef HAVE_SETGROUPS_INT */

/* Define to 1 if you have the `syscall' function. */
#define HAVE_SYSCALL 1
/* #undef HAVE_SYSCALL_INT */

/*************************** LIBRARIES ***************************/

/**************************** OPTIONS ****************************/

/* #undef HAVE_APPLE */

#define HAVE_LINUX_32BIT_SYSCALLS 1

#define HAVE_GCC_THREAD_LOCAL_STORAGE 1
#define HAVE_GCC_ATOMIC_BUILTINS 1
#define HAVE_CONSTRUCTOR_ATTRIBUTE 1
#define HAVE_DESTRUCTOR_ATTRIBUTE 1
#define HAVE_ADDRESS_SANITIZER_ATTRIBUTE 1
#define HAVE_FUNCTION_ATTRIBUTE_FORMAT 1

/*************************** ENDIAN *****************************/

/* Define WORDS_BIGENDIAN to 1 if your processor stores words with the most
   significant byte first (like Motorola and SPARC, unlike Intel). */
/* #undef WORDS_BIGENDIAN */
